@@ -1,6 +1,6 @@
-use crate::general::Approach;
 use crate::general::c_string_to_option_string;
 use crate::general::c_string_to_string;
+use crate::general::Approach;
 use crate::general::CGeneralOptions;
 use crate::general::COsrmRouteLeg;
 use crate::general::Coordinate;
@@ -275,7 +275,22 @@ impl MatchRequest {
         self
     }
 
+    fn validate(&mut self) -> Result<(), String> {
+        self.general_options.validate()
+    }
+
     pub fn run(&mut self, osrm: &Osrm) -> (Status, MatchResult) {
+        if let Err(msg) = self.validate() {
+            return (
+                Status::Error,
+                MatchResult {
+                    code: Some("Err".to_owned()),
+                    message: Some(msg),
+                    tracepoints: vec![],
+                    matchings: vec![],
+                },
+            );
+        }
         unsafe {
             let mut result: *mut CMatchResult = std::ptr::null_mut();
             let result_ptr: *mut *mut CMatchResult = &mut result;
